'FFSubmenu=Skalieren
'FFName=ScalePrint

'FFSkriptName=ScalePrint.vbs
'FFSkriptArchiv=ScalePrint.zip
'FFSkriptDirectory=\MeckiScript\ScalePrint
'FFSkriptFiles=\MeckiScript\ScalePrint\ScalePrint.pdf
'FFScriptProfile=FF_ScalePrint

'FFSkriptAuthor=Harald Maeckler
'FFVersion=2.90.0

' ********************************************************************
' ScalePrint.vbs (Skript fr FixFoto)
' Funktion:	Skalieren von Bildern als Vorbereitung zum Ausdrucken
'
' Copyright Harald Maeckler, Dsseldorf 2010 - 2021
'
'** Start Kurzbeschreibung *******************************************
' ScalePrint / Version 1.27
' ===============
' Das Skript dient dazu, Fotos fr den Bilderdienst vorzubereiten.
'
' Man kann ausgewhlte Bilder verlustlos kopieren, optional mit gleichzeitiger Umbenennung.
' Oder Bilder werden auf eine gewnschte Gre skaliert bzw. auf ein auswhlbares Format
' beschnitten und die dazugehrige Punktdichte skaliert.
' Die Grenbestimmung erfolgt entweder ber die Vorgabe einer Kantenlnge oder durch Be-
' schnitt auf eine Bildgre, die aus einem Belichterprofil ausgewhlt werden kann.
' Alle Mglichkeiten werden weiter unten im Einzelnen erlutert.
'
' Will man die Abarbeitung mehrerer Bilder vorzeitig abbrechen, muss man
' 
' 	- bei gewhlter Option 'Beschnitt'
' den angezeigtem Ausschneidedialog bei festgehaltener 'Backspace'-Taste mit 'Ausfhren' ab-
' schlieen.
'	- bei gewhlter Option 'Kopie' oder 'Kantenlnge'
' die Taste 'Backspace' bettigen und festhalten bis eine Rckmeldung erfolgt.
'
' Nach erfolgreicher Unterbrechung wird angezeigt, wie viel Bilder bisher bearbeitet wurden und
' es wird abgefragt, ob man ScalePrint beenden mchte.
'
' Auswahl
' ----------
' Hier wird festgelegt welche Bilder skaliert werden sollen.
' Will man alle Bilder der Computerliste bzw. der Bilderliste markieren, klickt man ein Bild an und
' bettigt dann die Tasten <Strg> + <A>.
'
' Kantenlnge
' ---------------
' Man hat die Wahl zwischen
'
'	- lngste Seite
'	- krzeste Seite
'	- maximale Breite
'	- maximale Lnge
'	- maximale Breite +
'	  maximale Hhe
'
' Die Kantenlnge wird in Pixel eingegeben.
' Wenn die Option 'nur verkleinern' aktiviert ist, werden Bilder mit einer kleineren Kantenlnge
' als vorgegeben nicht skaliert.
'
' Kopie
' ------
' Die ausgewhlten Bilder werden verlustfrei kopiert.
'
' Beschnitt
' -----------
' Man whlt aus den installierten Belichterprofilen ein Profil aus und dann die gewnschte Bilder-
' gre. Sie beinhaltet die Abmessungen und die vom Belichter empfohlene Punktdichte. Ist die im
' Profil aufgefhrte Punktdichte kleiner als 150 dpi, wird angeboten, diese auf 300 dpi anzuheben.
' Ein Sonderfall ist dpi = 1. Hier wird angenommen, dass die Abmessungen Pixelwerte sind, z.B. zur
' Vorbereitung von Bildern zur Darstellung auf einem TV- oder PC-Bildschirm. Die Abfrage nach 
' Erhhung der Punktdichte wird in diesem Fall unterdrckt.
'
' Nach Start der Skalierung wird fr jedes Bild der Schnittdialog mit proportionaler Schnitt-
' markierung, die beliebig verndert werden kann, geffnet. Mit 'Ausfhren' erfolgt der Beschnitt.
' Dann wird geprft, ob zur Erreichung der gewnschten Punktdichte herunter skaliert werden
' kann. Ist dies nicht der Fall, wird abgefragt: "Soll hoch skaliert werden?".
' Man kann sich dann fr 'Nein', 'Nie', 'Ja' oder 'Immer' entscheiden. Wird das Dialogfeld durch 
' Anklicken des Kreuzes rechts oben abgebrochen, entspricht das der Entscheidung fr 'Ja'.
'
' Ist die Option 'Beschnitt berspringen wenn Bildgre passt' aktiviert, wird bei Bildern, deren
' Seitenverhltnis mit einer Toleranz von ca. 3 % dem geforderten Seitenverhltnis entspricht, das
' ffnen des Schnittdialogs ausgelassen.
'
' Speicheroptionen (unwirksam beim 'Kopieren')
' ------------------------------------------------------
' - Schrfen
' Auf Wunsch werden die skalierten Bilder geschrft. Beim Schrfegrad kann man zwischen 'schwach',
' 'mittel' und 'stark' whlen. Das entspricht einer RGB-Schrfung von 20, 30 oder 40.
'
' - Exif- und IPTC-Daten lschen
' Bei JPG-Bildern knnen diese Daten auf Wunsch gelscht werden. Sie sind fr das Ausbelichten
' berflssig und wenn sie entfernt werden, wird dadurch die Dateigre etwas verkleinert.
'
' Speicherqualitt (unwirksam beim 'Kopieren')
' -----------------------------------------------------
' Bei JPG-Bildern wird damit die Komprimierung angegeben. Desto kleiner die Qualitt gewhlt wird,
' desto strker werden die Bilder komprimiert und damit die Dateigren verkleinert.
' Allerdings sollte der Wert keinesfalls kleiner als 60 % angegeben werden. Zu empfehlen ist 70 %
' bis 85 %. 
' Gibt man 0 ein, wird der in den FixFoto-Parametern definierte Wert verwendet.
'
' Speicherort
' --------------
' Die skalierten Bilder werden an einem beliegen Verzeichnis abgelegt. Bettigt man '...' wird ein
' Explorer geffnet, in dem der gewnschten Ordner ausgewhlt oder ein Ordner neu angelegt kann.
'
' Alternativ kann man bei Grenbestimmung durch Beschnitt das Belichterverzeichnis, das in den
' FF-Einstellungen unter Pfade definiert ist, als Speicherort whlen. Die Bilder werden dann in einem
' Unterordner, benannt nach der Bildgre, abgelegt.
' Der Unterordner wird, wenn nicht schon vorhanden, automatisch angelegt.

' Beim Speichern der Bilder wird jeweils geprft, ob im Ordner bereits ein Bild gleichen
' Namens existiert. Ist dies der Fall, wird dem Namen eine Nummer in Klammern hinzugefgt, also
' z. B. Name(1).jpg. Existiert auch dieser Name, wird die Nummer immer weiter erhht.
'
' Name + Nummer
' --------------------
' Normalerweise wird jeweils das skalierte Bilder unter seinem Ursprungsnamen im Speicherort abgelegt.
' Ist die Option 'Name + Numm.' aktiviert und ein Name eingegeben, erhalten alle Bilder diesen
' Namen mit fortlaufenderNummerierung - z.B. Urlaub_0001.JPG, Urlaub_0002.JPG usw. Dabei ist die
' Stellenzahl der Nummerierung zwischen 1 und 4 einstellbar.
' Sind nummerierte Bilder am Speicherort mit gleichem Namen und Nummerierung bereits vorhanden, wird
' die Nummerierung fortgesetzt - z.B. mit Urlaub_0003.JPG, Urlaub_0004.JPG, vorausgesetzt die Stellen-
' zahl der vorhandenen und neuen Nummerierung ist gleich.
' Optional kann das Aufnahmedatum im Format tt.mm.jjjj dem Namen hinzugefgt werden. Das sieht dann
' beispielsweise wie folgt aus: Urlaub_0001_03.05.2012.JPG, Urlaub_0002_03.05.2012.JPG usw.
'
' Update
' ---------
' Nach Bettigung der Taste 'Update' wird auf der Downloadseite des Skripts berprft, ob eine neuere
' Version vorliegt. Ist dies der Fall, wird angeboten die Downloadseite aufzurufen.
'
'
' Deinstallation
' ========
' Wird die Entfernung des Skripts gewnscht, kann mit der Tastenkombination Alt + D eine 
' Lschroutine aufgerufen werden. Nach einer Sicherheitsabfrage wird berprft, ob das 
' zugehrige zip-Archiv im Skriptordner abgelegt ist. Wenn ja, wird vor dem Lschen ange-
' boten, davon eine Sicherheitskopie an einem beliebigen Speicherort abzulegen. Dann werden
' nacheinander die Skriptdatei, die in der Registry dazugehrenden Daten und eventuelle
' Zusatzdateien gelscht. Abschlieend wird die FixFotoScript.ini bereinigt.
'
' Nach manueller Durchfhrung einer 'Automatischen Skriptkonfiguration' ist das Skript mit 
' allen Komponenten aus der FixFoto-Umgebung entfernt.
'
'
' Benutzung des Skripts auf eigene Gefahr!
'
' Copyright Harald Maeckler
'
'
' Die Anwendung des Skripts wird ausfhrlich in der Anleitung "Fr Bilderdienst vorbereiten"
' von Alfred Sa im Kapitel 3.1 erlutert.
'
'** Ende Kurzbeschreibung ********************************************
'
' Version 1.27 vom 06.02.2021	- Skalierungsanpassung 
' Version 1.26 vom 10.07.2019	- Solldichte wird nur noch bei 'Beschnitt' abgefragt
' Version 1.25 vom 29.07.2018	- Wird im Schnittdialog 'Schlieen' statt 'Ausfhren' bettigt,
'									kann man zwischen 'berspringen' Ja oder Nein whlen oder Skriptabbruch
'								- Updateadresse wurde angepasst
' Version 1.24 vom 27.03.2016	- Skript-URL gem Forenberarbeitung gendert
' Version 1.23 vom 06.01.2015	- defekte Bilddateien werden als solche erkannt
' Version 1.22 vom 02.08.2014	- bei 'Name + Nummer' wurde die Erkennung vorhandener
'									Nummerierung verbessert
'								- kein Abbruch wenn keine Bilder markiert sind
'								- berspringen von Bildern beim Beschneiden verhindert
' Version 1.21 vom 18.10.2013	- optional verlustlos kopieren
'								- bei 'Name + Numm.' Stellenzahl zwischen 1 und 4 whlbar
' Version 1.20 vom 10.03.2013	- Bug beim Eintrag der Pixelgre in die Exif-Daten beseitigt
' Version 1.19 vom 28.02.2013	- Funktion FF_SetTooltipDelay erst ab Version 3.40.52 zugelassen
' Version 1.18 vom 31.01.2013	- Updatefunktion gendert (jetzt mit Objekt "Microsoft.XMLHTTP")
' Version 1.17 vom 22.08.2012	- Defekten Bildfilter repariert
' Version 1.16 vom 03.08.2012	- Speicherort whlbar zwischen beliebigem Ordner und Belichterverzeichnis
' Version 1.15 vom 04.07.2012	- bei 'Neuer Name + Nummer' kann das Aufnahmedatum hinzugefgt werden
' Version 1.14 vom 19.03.2012	- Zielgre 'max. Breite + max. Hhe' hinzugefgt
'								- Updatefunktion auf den neuesten Stand gebracht
'								- Versionsangabe ohne Rahmen
'								- Abfangen des Fehlers bei gelschtem Zielverzeichnis
'								- Kurzbeschreibung berarbeitet (Kantenlnge und Update)
' Version 1.13 vom 02.02.2012	- Tooltips hinzugefgt
'								- Updatefunktion hinzgefgt
'								- Kurzbeschreibung berarbeitet
' Version 1.12 vom 17.09.2011	- Bildfilter um JPEG erweitert
' Version 1.11 vom 18.07.2011	- kleine Bugs beseitigt
' Version 1.10 vom 28.06.2011	- gesichert gegen Absturz bei Speichern mit Exif-Daten
' Version 1.09 vom 28.01.2011	- die Nummerierung lt. 1.08 beginnt jetzt immer mit der
'									hchsten vorhandenen Nummer + 1
' Version 1.08 vom 28.01.2011	- ist 'Neuer Name + Nummer' aktiviert und sind Bilder am Speicherort
'									bereits vorhanden, wird die Nummerierung fortgesetzt
'									wenn 'NummFortsetzend' auf true gesetzt ist
' Version 1.07 vom 27.01.2011	- Bug in der DPI-Skalierung beseitigt
' Version 1.06 vom 13.01.2011	- Bug im Schnittdialog bei Tausch Hoch/Quer beseitigt
' Version 1.05 vom 12.01.2011	- Bug beim Abbruch mit Backspace beseitigt
' Version 1.04 vom 09.01.2011	- Sonderfall dpi = 1 bei Belichterformat:
'									Abfrage nach alternativer Verwendung von dpi = 300 wird unterdrckt
' Version 1.03 vom 06.01.2011	- Bug bei 'krzeste Seite' beseitigt
' Version 1.02 vom 04.01.2011	- Bug bei der Bildnummerierung beseitigt
'								- Kurzbeschreibung berarbeitet
' Version 1.01 vom 27.12.2010	- Beschriftungsnderungen
'								- wenn Ist-Punktdichte < Soll-Punkdichte, dann Abfrage
'									hochskalieren: Nein / Nie / Ja / Immer
'								- Kurzbeschreibung
' Version 1.00 vom 24.12.2010	- Betaversion
' ********************************************************************

Option Explicit

'Updatekonstanten und Variable
const SkriptVersion = "1.27"
const SkriptURL = "https://www.ffsf.de/resources/scaleprint.164/"
Dim UrlVersion,UrlV_Zahl,SkriptV_Zahl,SkriptEnde

'Konstante
Const BildFilter = ":BMP:JP2:JPG:PNG:TIF:JPEG:"
const Zielvorgaben = "lngste Seite/krzeste Seite/maximale Breite/maximale Hhe/maximale Breite +"
const RGB_S = true : const Y_S = false
const Schaerfegrade = "schwach/mittel/stark"
const S_schwach = 20 : const S_mittel = 30 : const S_stark = 40
const Toleranz = 3 '% Abweichung max. zwischen SV-Soll und SV-Ist
const NummFortsetzend = true	'false bedeute, dass bei "Neuer Name + Nummer" die Nummerierung nicht fortgesetzt wird
Dim Uebersprung

Dim SkriptName
const Skript = "ScalePrint"									'Skriptname
const RegSchluessel = "FF_ScalePrint"						'Registryschlssel

Dim Kurzbeschreibung, KBvorhanden, LaengeMax, Abbruch		'Kurzbeschreibung
const ForReading = 1, ForWriting = 2
Abbruch = false

Dim objFS,WshShell											'Objekte
Set objFS = CreateObject("Scripting.FileSystemObject")
Set WshShell = CreateObject("WScript.Shell")

Dim SkriptKill,Antwort,TempFile	 : SkriptKill = false		'Lschroutine

Dim Array,element,Bilder,n,b,imgAnz

Dim Auswahl
Dim flag_Kopie
Dim flag_Ziel,Zielgroesse,Seitenlaenge,flag_MaxHoehe,Bildhoehe,flag_NurVerkleinern
Dim flag_Beschnitt,BelichterName,BelichterWert,flag_BsUeber
Dim FormatIndex,SMarkierung
Dim flag_Schaerfen,SchaerfeWert,flag_EI_loeschen
Dim Qualitaet
Dim Zielordner,flag_belOrdner,flag_BelichterVerzeichnis
Dim flag_Umbenennen,StAnz,NameNeu,mitDatum,k,DefAnz

Dim Anzeige
Dim strExtension,Bildname,IstHoehe,IstBreite,SV_BzuH,SollHoehe,SollBreite,SV_Soll
Dim IstDichte,SollDichte
Dim PunktdichteNie : PunktdichteNie = false
Dim PunktdichteImmer : PunktdichteImmer = false

const Reg_BildV = "HKCU\Software\Joachim Koopmann Software\FixFoto\Options\ProviderPath"
Dim Belichterpfad
'------------------------------------------------------------------------
call Main
if not Abbruch and flag_belOrdner = 1 then FF_SetImagePath Zielordner	'Computerverzeichnnis auffrischen
'------------------------------------------------------------------------
Sub Main	'### Hauptprogramm
Dim Ziel,OrdnerName,pos

on error resume next							'Kontrolle ob Skript in FF-Umgebung gestartet wurde
	FF_GetScriptPath
 	if Err.Number > 0 then
		msgbox "Das Skript funktioniert nur in der Programmumgebung von FixFoto!",vbCritical,"Abbruch"
		exit sub
	end if
on error goto 0

OrdnerName = FF_GetImagePath
if not objFS.FolderExists(OrdnerName) then
	msgbox "Der Ordner" & vbNewLine & OrdnerName & vbNewLine & "wurde gelscht." & vbNewLine & vbNewLine & _
		   "Das Computerverzeichnis wird jetzt aktualisiert" & vbNewLine & "und das Skript beendet.",vbExclamation,"Abbruch"
	do
		pos = InStrRev(OrdnerName,"\")
		if pos > 0 then
			OrdnerName = left(OrdnerName,pos -1)
			if objFS.FolderExists(OrdnerName) then exit do
		end if
	loop
	FF_SetImagePath OrdnerName
	exit sub
end if

if objFS.FileExists(FF_GetScriptPath & "\" & Skript & ".vbs") then
	SkriptName = Skript & ".vbs"
elseif objFS.FileExists(FF_GetScriptPath & "\" & Skript & ".vbe") then
	SkriptName = Skript & ".vbe"
else
	msgbox "Das Skript wurde umbenannt!",vbCritical,"Abbruch"
	exit sub
end if

'** Start Dialog ScalePrint **
FF_AddDialog "ScalePrint",381,152
FF_AddControl "ScalePrint","Auswahl","GROUP",5,13,124,40
FF_AddControl "ScalePrint","selCV","BOOL",9,25,8,8
FF_SetControlStyle "ScalePrint","selCV",16384
FF_AddControl "ScalePrint","markierte Bilder der Computer-Ansicht","STATIC",21,24,104,10
FF_AddControl "ScalePrint","selBL","BOOL",9,37,8,8
FF_SetControlStyle "ScalePrint","selBL",16384
FF_AddControl "ScalePrint","markierte Bilder der aktiven Bilderliste","STATIC",21,36,104,10
FF_AddControl "ScalePrint","Kantenlnge","GROUP",136,13,112,44
FF_AddControl "ScalePrint","flag_Ziel","BOOL",214,12,8,8
FF_SetControlStyle "ScalePrint","flag_Ziel",16384
FF_AddControl "ScalePrint","Zielgroesse","COMBO",142,24,60,10
FF_AddControl "ScalePrint","Seitenlaenge","SLEDIT",205,24,24,10
FF_SetControlStyle "ScalePrint","Seitenlaenge",8193
FF_AddControl "ScalePrint","px","STATIC",232,24,8,10
FF_AddControl "ScalePrint","flag_NurVerkleinern","BOOL",142,47,8,8
FF_AddControl "ScalePrint","nur verkleinern","STATIC",155,46,46,10
FF_AddControl "ScalePrint","Beschnitt","GROUP",251,13,108,72
FF_AddControl "ScalePrint","flag_Beschnitt","BOOL",343,12,8,8
FF_SetControlStyle "ScalePrint","flag_Beschnitt",16384
FF_AddControl "ScalePrint","Belichter","STATIC",256,21,32,10
FF_AddControl "ScalePrint","BelichterName","COMBO",256,31,96,10
FF_AddControl "ScalePrint","Bildgre","STATIC",256,43,38,10
FF_AddControl "ScalePrint","BelichterWert","COMBO",256,53,96,10
FF_AddControl "ScalePrint","flag_BsUeber","BOOL",256,70,8,8
FF_AddControl "ScalePrint","Beschnitt berspringen","STATIC",269,65,82,10
FF_AddControl "ScalePrint","wenn Bildgre passt","STATIC",269,73,82,10
FF_AddControl "ScalePrint","Speicheroptionen","GROUP",5,54,124,36
FF_AddControl "ScalePrint","flag_Schaerfen","BOOL",9,65,8,8
FF_AddControl "ScalePrint","Schrfen","STATIC",21,64,33,10
FF_AddControl "ScalePrint","SchaerfeWert","COMBO",56,64,40,10
FF_AddControl "ScalePrint","flag_EI_loeschen","BOOL",9,78,8,8
FF_AddControl "ScalePrint","Exif- und IPTC-Daten lschen","STATIC",21,77,90,10
FF_AddControl "ScalePrint","Speicherqualitt","GROUP",136,59,112,31
FF_AddControl "ScalePrint","Qualitaet","SLEDIT",142,68,20,10
FF_SetControlStyle "ScalePrint","Qualitaet",8193
FF_AddControl "ScalePrint","60 - 100 %","STATIC",176,68,44,10
FF_AddControl "ScalePrint","0 % = FixFoto-Einstellung","STATIC",142,78,80,10
FF_AddControl "ScalePrint","Speicherort","GROUP",5,91,243,35
FF_AddControl "ScalePrint","Zielordner","SLEDIT",22,101,200,10
FF_AddControl "ScalePrint","...","BUTTON",228,101,14,10
FF_AddControl "ScalePrint","Name + Numm.","GROUP",251,91,108,35
FF_AddControl "ScalePrint","StAnz","COMBO",297,89,20,10
FF_AddControl "ScalePrint","flag_Umbenennen","BOOL",343,90,8,8
FF_SetControlStyle "ScalePrint","flag_Umbenennen",16384
FF_AddControl "ScalePrint","NameNeu","SLEDIT",256,101,96,10
FF_AddControl "ScalePrint","Fortschritt","PROGRESS",5,130,354,4
FF_AddControl "ScalePrint","?","BUTTON",9,138,11,11
FF_AddControl "ScalePrint","Update","BUTTON",51,138,33,11
FF_AddControl "ScalePrint","Vorgang abrechen mit","STATIC",106,138,54,11
FF_AddControl "ScalePrint","Backspace","BUTTON",163,139,36,9
FF_AddControl "ScalePrint","- Taste","STATIC",201,138,20,11
FF_AddControl "ScalePrint","Beenden","BUTTON",271,138,33,11
FF_AddControl "ScalePrint","Start","BUTTON",320,138,33,11
FF_AddControl "ScalePrint","&delete","BUTTON",2,2,1,1
FF_AddControl "ScalePrint","---- nur kopieren oder Grenbestimmung  durch skalieren ---------------------------------------------------------------------------------","STATIC",43,2,293,8
FF_AddControl "ScalePrint","flag_MaxHoehe","BOOL",142,37,8,8
FF_AddControl "ScalePrint","maximale Hhe","STATIC",155,36,46,10
FF_AddControl "ScalePrint","HoeheMax","SLEDIT",205,36,24,10
FF_SetControlStyle "ScalePrint","HoeheMax",8193
FF_AddControl "ScalePrint","px|","STATIC",232,36,8,10
FF_AddControl "ScalePrint","|","STATIC",24,138,24,11
FF_SetControlStyle "ScalePrint","|",1
FF_AddControl "ScalePrint","mitDatum","BOOL",256,114,8,8
FF_AddControl "ScalePrint","+ Aufnahmedatum (tt.mm.jjjj)","STATIC",265,113,86,10
FF_AddControl "ScalePrint","flag_belOrdner","BOOL",9,102,8,8
FF_SetControlStyle "ScalePrint","flag_belOrdner",16384
FF_AddControl "ScalePrint","flag_BelichterVerzeichnis","BOOL",9,114,8,8
FF_SetControlStyle "ScalePrint","flag_BelichterVerzeichnis",16384
FF_AddControl "ScalePrint","Unterordner 'Bildgre' des Belichterverzeichnisses (FF-Einstellungen -> Pfade)","STATIC",22,113,220,10
FF_AddControl "ScalePrint","flag_Kopie","BOOL",35,2,8,8
FF_SetControlStyle "ScalePrint","flag_Kopie",16384
FF_AddControl "ScalePrint","-stellig","STATIC",318,89,24,10
FF_AddControl "ScalePrint","v","STATIC",214,2,8,8
FF_SetControlStyle "ScalePrint","v",1
FF_AddControl "ScalePrint","|v","STATIC",343,2,8,8
FF_SetControlStyle "ScalePrint","|v",1
FF_AddControl "ScalePrint","bzw. beschneiden","STATIC",242,2,80,8
FF_SetControlStyle "ScalePrint","bzw. beschneiden",1
'** End Dialog ScalePrint **

Array = split(Zielvorgaben,"/")
for each element in Array
	FF_SetControl "ScalePrint","Zielgroesse",element
next

Array = split(FF_PSGetList,vbNewLine)
for each element in Array
	FF_SetControl "ScalePrint","BelichterName",element
next

Array = split(Schaerfegrade,"/")
for each element in Array
	FF_SetControl "ScalePrint","SchaerfeWert",element
next

for n = 1 to 4
	FF_SetControl "ScalePrint","StAnz",n
next

call RegistryLesen

if flag_Kopie = 1 then
	FF_EnableControl "ScalePrint","BelichterName", false
	FF_EnableControl "ScalePrint","BelichterWert", false
	FF_EnableControl "ScalePrint","flag_BsUeber", false
	FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
	FF_EnableControl "ScalePrint","Zielgroesse", false
	FF_EnableControl "ScalePrint","Seitenlaenge", false
	FF_EnableControl "ScalePrint","HoeheMax", false
	FF_EnableControl "ScalePrint","flag_NurVerkleinern", false
	FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
	FF_EnableControl "ScalePrint","flag_Schaerfen", false
	FF_EnableControl "ScalePrint","SchaerfeWert", false
	FF_EnableControl "ScalePrint","flag_EI_loeschen", false
	FF_EnableControl "ScalePrint","Qualitaet", false
elseif flag_Ziel = 1 then
	FF_EnableControl "ScalePrint","BelichterName", false
	FF_EnableControl "ScalePrint","BelichterWert", false
	FF_EnableControl "ScalePrint","flag_BsUeber", false
	FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
else
	FF_EnableControl "ScalePrint","Zielgroesse", false
	FF_EnableControl "ScalePrint","Seitenlaenge", false
	FF_EnableControl "ScalePrint","HoeheMax", false
	FF_EnableControl "ScalePrint","flag_NurVerkleinern", false
end if

if flag_Umbenennen = 1 then
	FF_EnableControl "ScalePrint","NameNeu", true
	FF_EnableControl "ScalePrint","mitDatum", true
else
	FF_EnableControl "ScalePrint","NameNeu", false
	FF_EnableControl "ScalePrint","mitDatum", false
end if

FF_SetControl "ScalePrint","flag_MaxHoehe",flag_MaxHoehe
FF_EnableControl "ScalePrint","flag_MaxHoehe",false

if flag_BelichterVerzeichnis = 1 then
	call BelPfad_Lesen
	if Abbruch then
		msgbox "Die Auswahl Belichterverzeichnis als Speicherort wird deaktiviert!",vbInformation,"Hinweis"
		FF_SetControl "ScalePrint","flag_belOrdner",1
		FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",0
		FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
		Abbruch = false
	end if
end if

'Tooltips
if Version_OK("3.30.06") then
	FF_SetControlTooltip "ScalePrint","Zielordner",Zielordner
	FF_SetControlTooltip "ScalePrint","NameNeu", "" &_
						 "An den eingegebenen Namen wird eine" & vbNewLine &_
						 "vierstellige Nummer angehngt und ggf." & vbNewLine &_
						 "das Aufnahmedatum."
	FF_SetControlTooltip "ScalePrint","Qualitaet", "" &_
						 "Qualitt der einzufgenden Bilder." & vbNewLine & "Bei 0 wird die FixFoto-Einstellung verwendet."
	FF_SetControlTooltip "ScalePrint","...","Aufruf des Dateiexplorers"
	FF_SetControlTooltip "ScalePrint","?", "" &_
						 "Anzeige der Kurzbeschreibung als PDF-Datei," & vbNewLine & _
						 "vorausgesetzt es ist ein PDF-Reader installiert." & vbNewLine & _
						 "Anderenfalls wird eine gekrzte Textversion angezeigt."
	FF_SetControlTooltip "ScalePrint","Update", "" &_
						 "Prfung ob eine neue Version vorliegt."
end if

if Version_OK("3.40.52") then FF_SetTooltipDelay 2500
FF_ActivateControl "ScalePrint","&delete"
FF_SetDialogTimer "ScalePrint", 100

do
	Abbruch = false
	if Version_OK("3.30.06") then
		FF_SetControlTooltip "ScalePrint","BelichterName",BelichterName
		BelichterWert = FF_GetControl ("ScalePrint","BelichterWert")
		FF_SetControlTooltip "ScalePrint","BelichterWert",BelichterWert
		FF_SetControlTooltip "ScalePrint","flag_BelichterVerzeichnis",objFS.BuildPath(Belichterpfad,BelichterWert)
		FF_SetControlTooltip "ScalePrint","Zielordner",Zielordner
		if FF_GetControl("ScalePrint","flag_Beschnitt") = 1 then
			FF_SetControlTooltip "ScalePrint","Backspace", "" &_
						 "Vorzeitiger Abbruch mglich durch" & vbNewLine & "'Ausfhren' des Ausschneidedialogs" & vbNewLine &_
						 "bei festgehaltener 'Backspace'-Taste."
		else
			FF_SetControlTooltip "ScalePrint","Backspace", "" &_
						 "Vorzeitiger Abbruch mglich durch" & vbNewLine & "Festhalten der 'Backspace'-Taste bis" & vbNewLine &_
						 "eine Rckmeldung erfolgt."
		end if
	end if
			
	Select Case FF_ShowDialog ("ScalePrint")

	Case "TIMER"
		FF_SetDialogTimer "ScalePrint", 0
		FF_SetControl "ScalePrint" ,"|", "V " & Skriptversion
	Case "&delete"
		Antwort = msgbox("Soll das Skript " & SkriptName & vbNewline & _
						 "wirklich gelscht werden?", _
						 vbYesNo + vbQuestion,"Sicherheitsabfrage")
		if Antwort = vbYes then
			SkriptKill = true
			exit do
		end if
	Case "selCV"		'Auswahl markierte in der Comp.-Ansicht
		Auswahl = 1
		FF_SetControl "ScalePrint","selCV",1
		FF_SetControl "ScalePrint","selBL",0	
	Case "selBL"		'Auswahl markierte in der aktuellen Bilderliste
		Auswahl = 3
		FF_SetControl "ScalePrint","selCV",0
		FF_SetControl "ScalePrint","selBL",1
	Case "flag_Kopie"
		FF_SetControl "ScalePrint","flag_Kopie",1
		FF_SetControl "ScalePrint","flag_Ziel",0
		FF_SetControl "ScalePrint","flag_Beschnitt",0
		
		FF_EnableControl "ScalePrint","Zielgroesse", false
		FF_EnableControl "ScalePrint","Seitenlaenge", false
		FF_EnableControl "ScalePrint","HoeheMax", false
		FF_EnableControl "ScalePrint","flag_NurVerkleinern", false
		
		FF_EnableControl "ScalePrint","BelichterName", false
		FF_EnableControl "ScalePrint","BelichterWert", false
		FF_EnableControl "ScalePrint","flag_BsUeber", false
		
		FF_EnableControl "ScalePrint","flag_Schaerfen", false
		FF_EnableControl "ScalePrint","SchaerfeWert", false
		FF_EnableControl "ScalePrint","flag_EI_loeschen", false
		FF_EnableControl "ScalePrint","Qualitaet", false
		
		FF_SetControl "ScalePrint","flag_belOrdner",1
		FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",0
		FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
	Case "flag_Ziel"
		FF_SetControl "ScalePrint","flag_Kopie",0
		FF_SetControl "ScalePrint","flag_Ziel",1
		FF_SetControl "ScalePrint","flag_Beschnitt",0
		
		FF_EnableControl "ScalePrint","Zielgroesse", true
		FF_EnableControl "ScalePrint","Seitenlaenge", true
		FF_EnableControl "ScalePrint","HoeheMax", true
		FF_EnableControl "ScalePrint","flag_NurVerkleinern", true
		
		FF_EnableControl "ScalePrint","BelichterName", false
		FF_EnableControl "ScalePrint","BelichterWert", false
		FF_EnableControl "ScalePrint","flag_BsUeber", false

		FF_EnableControl "ScalePrint","flag_Schaerfen", true
		FF_EnableControl "ScalePrint","SchaerfeWert", true
		FF_EnableControl "ScalePrint","flag_EI_loeschen", true
		FF_EnableControl "ScalePrint","Qualitaet", true

		FF_SetControl "ScalePrint","flag_belOrdner",1
		FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",0
		FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
	Case "flag_Beschnitt"
		FF_SetControl "ScalePrint","flag_Kopie",0
		FF_SetControl "ScalePrint","flag_Ziel",0
		FF_SetControl "ScalePrint","flag_Beschnitt",1
		
		FF_EnableControl "ScalePrint","Zielgroesse", false
		FF_EnableControl "ScalePrint","Seitenlaenge", false
		FF_EnableControl "ScalePrint","HoeheMax", false
		FF_EnableControl "ScalePrint","flag_NurVerkleinern", false
		
		FF_EnableControl "ScalePrint","BelichterName", true
		FF_EnableControl "ScalePrint","BelichterWert", true
		FF_EnableControl "ScalePrint","flag_BsUeber", true

		FF_EnableControl "ScalePrint","flag_Schaerfen", true
		FF_EnableControl "ScalePrint","SchaerfeWert", true
		FF_EnableControl "ScalePrint","flag_EI_loeschen", true
		FF_EnableControl "ScalePrint","Qualitaet", true

		FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", true
	Case "Zielgroesse"
		if FF_GetControl("ScalePrint","Zielgroesse") = "maximale Breite +" then
			FF_SetControl "ScalePrint","flag_MaxHoehe",1
			FF_EnableControl "ScalePrint","HoeheMax",true
		else
			FF_SetControl "ScalePrint","flag_MaxHoehe",0
			FF_EnableControl "ScalePrint","HoeheMax",false
		end if
	Case "BelichterName"
		BelichterName = FF_GetControl ("ScalePrint","BelichterName")
		FF_SetControl "ScalePrint","BelichterWert",""
		for n = 0 to FF_PSGetFormatCount(BelichterName) -1
			FF_SetControl "ScalePrint","BelichterWert",FF_PSGetFormatName(BelichterName,n)
		next
	Case "BelichterWert"
		'nur zur Tooltipperzeugung
	Case "flag_belOrdner"
		FF_SetControl "ScalePrint","flag_belOrdner",1
		FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",0
	Case "flag_BelichterVerzeichnis"
		call BelPfad_Lesen
		if Abbruch then
			msgbox "Die Auswahl Belichterverzeichnis als Speicherort wird deaktiviert!",vbInformation,"Hinweis"
			FF_SetControl "ScalePrint","flag_belOrdner",1
			FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",0
			FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
			Abbruch = false
		else
			FF_SetControl "ScalePrint","flag_belOrdner",0
			FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",1
		end if
	Case "..."
		FF_SetCurrentPath Zielordner
		Ziel = FF_EnterPath(false,"Wahl des Ablageordners")
		if len(Ziel) > 2 then
			Zielordner = Ziel
			FF_SetControl "ScalePrint","Zielordner",Zielordner
		end if
	Case "flag_Umbenennen"
		flag_Umbenennen = FF_GetControl ("ScalePrint","flag_Umbenennen")
		if flag_Umbenennen = 1 then
			FF_EnableControl "ScalePrint","NameNeu", true
			FF_EnableControl "ScalePrint","mitDatum", true
		else
			FF_EnableControl "ScalePrint","NameNeu", false
			FF_EnableControl "ScalePrint","mitDatum", false
		end if
	Case "?"
		'FF_SetControl "ScalePrint","Fortschritt",65	'############## nur fr Screenshot
		Anzeige = """" & FF_GetScriptPath & "\MeckiScript\ScalePrint\ScalePrint.pdf" & """"
		on error resume next
		WshShell.Run Anzeige,1,false
		if err <> 0 then
			msgbox "Die Kurzbeschreibung konnte nicht als PDF-Datei geffnet werden." & vbNewLine & _
				   "Die Datei ist gelscht oder es ist kein PDF-Reader installiert (?)." & vbNewLine & vbNewLine &_
				   "Ersatzweise erfolgt eine Textanzeige!",vbExclamation,"Hinweis"
			err.clear
			
			if not KBvorhanden then	call KurzbeschreibungLesen
			if KBvorhanden then
				call KurzbeschreibungAnzeigen
			else
				msgbox "Keine Kurzbeschreibung gefunden!",vbExclamation,"Meldung"
			end if
			
		end if
		on error GoTo 0
	Case "Update"
		SkriptEnde = false
		call Update
		if SkriptEnde then exit do
	Case "Start"
		call WerteAuslesen
		'Bilder vorhanden?
		Array = split(Bilder, vbNewLine)
		imgAnz = ubound(Array) + 1
		if len(Bilder) = 0 then
			msgbox "Es ist kein Bild markiert!",vbExclamation,"Meldung"
			Abbruch = true
		end if
		if not Abbruch then call Kontrolle
		if not Abbruch then
				if flag_BelichterVerzeichnis = 1 then
					call BelPfad_Lesen
					if Abbruch then
						msgbox "Die Auswahl Belichterverzeichnis als Speicherort wird deaktiviert!",vbInformation,"Hinweis"
						flag_belOrdner = 1 : flag_BelichterVerzeichnis = 0
						FF_SetControl "ScalePrint","flag_belOrdner",1
						FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",0
						FF_EnableControl "ScalePrint","flag_BelichterVerzeichnis", false
						Abbruch = false
					end if
				end if
				if flag_BelichterVerzeichnis = 0 then
					Antwort = msgbox("Es sind " & imgAnz & " Bilder zu bearbeiten." & vbNewLine & _
									 "Sie werden jeweils im Ordner" & vbNewLine & _
									  Zielordner & vbNewLine & "abgespeichert." & vbNewLine & vbNewLine & _
									 "Ist das in Ordnung?",vbQuestion + vbYesNo,"Speicherort")
				else
					Antwort = msgbox("Es sind " & imgAnz & " Bilder zu bearbeiten." & vbNewLine & _
									 "Sie werden jeweils im Unterordner" & vbNewLine & _
									 "'" & BelichterWert & "'" & vbNewLine & _
									 "des Belichterverzeichnisses" & vbNewLine & _
									 BelichterPfad  & vbNewLine & _
									 "abgespeichert." & vbNewLine & vbNewLine & _
									 "Ist das in Ordnung?",vbQuestion + vbYesNo,"Speicherort")
				end if
				if Antwort = vbYes then
					call Bildschleife
					exit do
				end if
		end if
	Case "Beenden","CANCEL"
		Abbruch = true
		exit do
	Case Else
	End Select
loop

call RegistrySchreiben
FF_CloseDialog ("ScalePrint")
if SkriptKill then	'ggf. Skript komplett entfernen
	call KillSkript
end if

End sub
'------------------------------------------------------------------------
Sub KurzbeschreibungAnzeigen

Dim Taste
Dim TBreite	: TBreite = LaengeMax * 2.6 + 10
const THoehe = 180

const ES_READONLY = 2048
const WS_VSCROLL = 2097152

FF_AddDialog "Kurzbeschreibung",TBreite,THoehe
FF_AddControl "Kurzbeschreibung","Beschreibung","EDIT",0,0,TBreite,THoehe-20
FF_SetControlStyle "Kurzbeschreibung","Beschreibung", ES_READONLY + WS_VSCROLL
FF_AddControl "Kurzbeschreibung","OK","BUTTON",TBreite/2-15,THoehe-15,30,10

FF_SetControl "Kurzbeschreibung","Beschreibung",Kurzbeschreibung

do
	Taste = FF_ShowDialog("Kurzbeschreibung")
	if Taste = "CANCEL" or Taste = "OK" then exit do
loop
call FF_CloseDialog("Kurzbeschreibung")

End Sub
'------------------------------------------------------------------------
Sub KurzbeschreibungLesen
on error resume next
Const ForReading = 1
Dim Skript, Anfang, Ende, Zeile

Set Skript = objFS.OpenTextFile(FF_GetScriptPath & "\" & SkriptName, ForReading, False)

if err.number = 53 then
	msgbox "Wahrscheinlich wurde der Originalskriptname " & """" & SkriptName & """" & " abgendert." & vbNewLine & _
		   "Die Kurzbeschreibung kann daher nicht angezeigt werden.",vbExclamation,"Meldung"
	Abbruch = True
	exit sub
end if

Do While Skript.AtEndOfStream <> True
	Zeile = Skript.ReadLine
	
	if instr(Zeile,"** Ende Kurzbeschreibung") > 0 then Ende = true
	if Ende then exit do
	
	if Anfang then Kurzbeschreibung = Kurzbeschreibung & mid(Zeile,2) & vbNewLine
	if len(Zeile)-1 > LaengeMax then LaengeMax = len(Zeile)-1
	
	if instr(Zeile,"** Start Kurzbeschreibung") > 0 then Anfang = true
	
Loop
	
if Anfang and Ende then KBvorhanden = true
Skript.Close

End Sub
'------------------------------------------------------------------------
Function Version_OK(MinVersion)
dim VersNr

 VersNr=split(MinVersion,".")
 Version_OK=FF_GetMajor * 1000 + FF_GetMinor + FF_GetBuild / 1000 >=_
     		VersNr(0) * 1000 + VersNr(1) + VersNr(2) / 1000

End Function
'------------------------------------------------------------------------
Sub KillSkript
'Skript mit allen Komponenten entfernen

Dim SPfad

'### FixFotoScript.ini bereinigen
TempFile = FF_GetFFPathEx(1) & "\FixFotoScript.ini"
if objFS.FileExists(TempFile) then
	call IniBereinigung
	if Abbruch then exit sub
else
	msgbox 	"Die Datei FixFotoScript.ini konnte nicht gefunden werden." & vbNewLine & _
			"Der Lschvorgang wird abgebrochen!",vbExclamation,"Hinweis"
	exit sub
end if

'### zip-Archiv auf Wunsch sichern, dann lschen
TempFile = FF_GetScriptPath & "\" & objFS.GetBaseName(Skriptname) & ".zip"
if objFS.FileExists(TempFile) then
	Antwort = msgbox("Soll das Archiv " & objFS.GetBaseName(Skriptname) & ".zip" & _
			 " gesichert werden?",vbYesNo + vbQuestion,"Sicherheitskopie")
	if Antwort = vbYes then
		SPfad = FF_EnterPath(true,"Wo soll die Sicherheitskopie angelegt werden?")
		if SPfad = "" then
			msgbox "Das Lschen des Skripts wird abgebrochen!",vbExclamation,"Hinweis"
			exit sub
		end if
		SPfad = SPfad & "\" & objFS.GetBaseName(Skriptname) & ".zip"
		objFS.CopyFile Tempfile, SPfad, true
	end if
	objFS.DeleteFile TempFile,true
end if

'### Skriptdatei lschen
TempFile = FF_GetScriptPath & "\" & Skriptname
objFS.DeleteFile TempFile,true

'### evtl. beigepackte bzw. erzeugte Dateien und Ordner lschen
'TempFile = """" & FF_GetScriptPath & "\ScalePrint\ScalePrint.pdf" & """"
'if objFS.FileExists(TempFile) then objFS.DeleteFile TempFile,true

TempFile = FF_GetScriptPath & "\MeckiScript\ScalePrint"						'Ordner
if objFS.FolderExists(TempFile) then objFS.DeleteFolder TempFile,true

'### ggf. Registry-Daten lschen
TempFile = "HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Script\" & RegSchluessel & "\"
WshShell.RegDelete(TempFile)

'### Fertigmeldung
msgbox "Das Skript" & Skriptname & vbNewLine & "wurde mit allen Komponenten gelscht!" & vbNewLine & _
	   "Es wird empfohlen die 'Automatische Skriptkonfiguration' aufzurufen.",vbExclamation,"Hinweis"

End Sub
'------------------------------------------------------------------------
Sub IniBereinigung
'FixFotoScript.ini - Bereinigung

Dim Zeile, zNr,Anfang, Ende, DateiTmp, ZielZeile, tmpString
DateiTmp =  FF_GetFFPathEx(1) & "\FixFotoScript.tmp"

'### Wo befindet sich der Eintrag zum Skript?
Set Zeile = objFS.OpenTextFile(TempFile, ForReading)

zNr = 0
do Until Zeile.AtEndOfStream
	tmpString = Zeile.ReadLine
	zNr = zNr + 1
	if tmpString = "[Script]" then Anfang = zNr
	if tmpString = "File=.\" & Skriptname then
		Ende = zNr
		exit do	
	end if
loop 
Zeile.Close

if Ende <= Anfang then
	msgbox 	"Die Datei FixFotoScript.ini konnte nicht bereinigt werden." & vbNewLine & _
		"Der Lschvorgang wird abgebrochen!",vbExclamation,"Hinweis"
	Abbruch = true
	exit sub
end if

'### Zeilen ohne skriptbezogene Zeilen in DateiTmp bertragen
Set Zeile = objFS.OpenTextFile(TempFile, ForReading)
Set ZielZeile  = objFS.CreateTextFile(DateiTmp, True)

zNr = 0
do Until Zeile.AtEndOfStream
	tmpString = Zeile.ReadLine
	zNr = zNr + 1
	if zNr < Anfang or zNr > Ende then
		ZielZeile.WriteLine tmpString
	end if
loop 

Zeile.Close
ZielZeile.Close

'### Umkopieren von DateiTmp nach FixFotoScript.ini (TempFile)
objFS.CopyFile DateiTmp, TempFile, True
objFS.DeleteFile (DateiTmp)

End Sub
'------------------------------------------------------------------------
Sub WerteAuslesen

'Auswahl
if FF_GetControl ("ScalePrint","selCV") = 1 then Auswahl = 1	'markierte Dateien der Computeransicht
if FF_GetControl ("ScalePrint","selBL") = 1 then Auswahl = 3	'markierte Dateien der aktuellen Bilderliste
Bilder = FF_GetSelection(Auswahl)

'Zielgre
flag_Kopie = FF_GetControl ("ScalePrint","flag_Kopie")
flag_Ziel = FF_GetControl ("ScalePrint","flag_Ziel")
Zielgroesse = FF_GetControl ("ScalePrint","Zielgroesse")
	if Zielgroesse = "maximale Breite +" then flag_MaxHoehe = 1 else flag_MaxHoehe = 0
	FF_SetControl "ScalePrint","flag_MaxHoehe",flag_MaxHoehe
Seitenlaenge = FF_GetControl ("ScalePrint","Seitenlaenge")
	if Seitenlaenge = "" then Seitenlaenge = 0
	Seitenlaenge = Seitenlaenge *1
Bildhoehe = FF_GetControl ("ScalePrint","HoeheMax")
	if Bildhoehe = "" then Bildhoehe = 0
	Bildhoehe = Bildhoehe *1
flag_NurVerkleinern = FF_GetControl ("ScalePrint","flag_NurVerkleinern")

'Beschnitt
flag_Beschnitt = FF_GetControl ("ScalePrint","flag_Beschnitt")
BelichterName = FF_GetControl ("ScalePrint","BelichterName")
BelichterWert = FF_GetControl ("ScalePrint","BelichterWert")
for n = 0 to FF_PSGetFormatCount(BelichterName) - 1
	if BelichterWert = FF_PSGetFormatName(BelichterName,n) then
		FormatIndex = n
		exit for
	end if
next
flag_BsUeber = FF_GetControl ("ScalePrint","flag_BsUeber")

'Speicheroptionen
flag_Schaerfen = FF_GetControl ("ScalePrint","flag_Schaerfen")
SchaerfeWert = FF_GetControl ("ScalePrint","SchaerfeWert")
flag_EI_loeschen = FF_GetControl ("ScalePrint","flag_EI_loeschen")

'Speicherqualitt
Qualitaet = FF_GetControl ("ScalePrint","Qualitaet")
if Qualitaet = "" then
	Qualitaet = 0
	FF_SetControl "ScalePrint","Qualitaet",0
end if

'Speicherort
flag_belOrdner = FF_GetControl ("ScalePrint","flag_belOrdner")
flag_BelichterVerzeichnis = FF_GetControl ("ScalePrint","flag_BelichterVerzeichnis")
Zielordner = FF_GetControl ("ScalePrint","Zielordner")

'Umbenennung
flag_Umbenennen = FF_GetControl ("ScalePrint","flag_Umbenennen")
StAnz = FF_GetControl ("ScalePrint","StAnz")
NameNeu = FF_GetControl ("ScalePrint","NameNeu")
mitDatum = FF_GetControl ("ScalePrint","mitDatum")

End Sub
'------------------------------------------------------------------------
Sub Kontrolle

'Versionstest fr Auswahl
if Auswahl > 1 then		'Auswahl aktiver Bilderliste
	if not Version_OK("2.90.0") then
		msgbox "Um die Auswahl aktiver Bilderlisten nutzen zu knnen" & vbNewLine & _
			   "ist mindestens FixFoto-Version 2.90 erforderlich.",vbCritical,"Hinweis"
		Abbruch = true
		exit sub
	end if
end if

'Zielgre
if flag_Ziel = 1 then
	if flag_MaxHoehe = 1 then
		if Seitenlaenge = 0 then
			msgbox "Achtung: Es muss ein Wert fr die" & vbNewLine & _
				   "max. Breite angegeben werden!",vbExclamation,"Warnung"
			Abbruch = true : exit sub		
		elseif Bildhoehe = 0 then
			msgbox "Achtung: Es muss ein Wert fr die" & vbNewLine & _
				   "max. Hhe angegeben werden!",vbExclamation,"Warnung"
			Abbruch = true : exit sub
		end if
	else
		if Seitenlaenge = 0 then
			msgbox "Achtung: Es muss ein Wert fr die" & vbNewLine & _
				   "Seitenlnge angegeben werden!",vbExclamation,"Warnung"
			Abbruch = true : exit sub
		end if
	end if
end if

'Beschnitt
if flag_Beschnitt = 1 and BelichterName = "" then
	msgbox "Es ist kein Belichter vorhanden!",vbExclamation,"Meldung"
	Abbruch = true
	exit sub
end if

if flag_Beschnitt = 1 and BelichterWert = "" then
	msgbox "Dem Belichterprofil " & BelichterName & vbNewLine & "ist keine Bildgre zugeordnet!",vbExclamation,"Meldung"
	Abbruch = true
	exit sub
end if

'Speicherqualitt
if Qualitaet <> 0 and (Qualitaet < 60 or Qualitaet > 100) then
	msgbox "Die Speicherqualitt muss 0 sein" & vbNewLine & "oder zwischen 60 % und 100 % betragen!",vbExclamation,"Meldung"
	Abbruch = true
	exit sub
end if

'Speicherort
if Zielordner = "" then
	msgbox "Achtung: Es muss ein Zielordner angegeben werden!",vbExclamation,"Meldung"
	Abbruch = true
	exit sub
end if

if not objFS.FolderExists(Zielordner) then
	msgbox "Das Verzeichnis" & vbNewLine & Zielordner & vbNewLine & "als Speicherort existiert nicht." & vbNewLine & _
		   "Es muss neu angelegt werden!",vbExclamation,"Meldung"
	FF_SetControl "Scaleprint","Zielordner",""
	Abbruch = true
	exit sub
end if

'Umbenennung
if flag_Umbenennen = 1 then
	if NameNeu = "" then
		msgbox "Fr die Umbenennung wurde kein Name eingegeben!",vbExclamation,"Meldung"
		Abbruch = true
		exit sub
	end if

	if len(imgAnz) > StAnz *1 then
		msgbox "Zur Nummerierung wurde fr die" & vbNewLine & _
			   imgAnz & " ausgewhlten Bilder eine zu" & vbNewLine &_
			   "kleine Stellenzahl ausgewhlt." & vbNewLine & _
			   "Sie muss mindestens " & len(imgAnz) & " betragen!",vbExclamation,"Meldung"
		Abbruch = true
		exit sub
	end if
	
	if NummFortsetzend then
		k = MaxNummer(Zielordner,NameNeu & "_")
		if k = "" then
			k = 0
		else
			if len(k) <> Stanz *1 then
				Antwort = msgbox ("Die im Zielordner abgelegten Bilder" & vbNewLine & _
								  "mit gleicher Benennung haben eine" & vbNewLine & _
					   			  len(k) & "-stellige Nummerierung." & vbNewLine & vbNewLine & _
					   			  "Eingestellt ist aber eine " & StAnz & "-stellige."  & vbNewLine & _
					   			  "Dadurch funktioniert die fortlaufende" & vbNewLine & _
					   			  "Nummerierung nicht." & vbNewLine & vbNewline & _
					   			  "Stattdessen werden sie " & StAnz & "-stellig mit 1 beginnend neu benannt.",vbOkCancel + vbQuestion,"Hinweis")
				if Antwort = vbCancel then Abbruch = true : exit sub
				k = 0
			else
				if IsNumeric(k) then k = k * 1 else k = 0
				if len(k + imgAnz) > StAnz  *1 then
					msgbox "Im Zielordner sind bereits " & k & " Bilder" & vbNewLine & _
							"mit gleicher Benennung vorhanden." & vbNewLine & _
							"Mit den " & imgAnz & " zu bearbeitenden Bildern" & vbNewLine & _
							"ergibt sich eine zu hohe Zahl fr die" & vbNewLine & _
							"eingestellte Stellenzahl." & vbNewLine & _
							"Sie muss mindestens " & len(k + imgAnz) & " betragen!",vbExclamation,"Abbruch"
					Abbruch = true
					exit sub
				end if
			end if
		end if
	end if
end if

End Sub
'------------------------------------------------------------------------
Sub RegistryLesen
'Schlsselname = HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Script\ & RegSchluessel

'### Werte auslesen

'Auswahl
Auswahl = FF_GetProfile (RegSchluessel,"Auswahl")
if Auswahl = "" then Auswahl = 1

'Kopie
flag_Kopie = FF_GetProfile (RegSchluessel,"flag_Kopie")
if flag_Kopie = "" then flag_Kopie = 0

'Zielgre
flag_Ziel = FF_GetProfile (RegSchluessel,"flag_Ziel")
if flag_Ziel = "" then flag_Ziel = 1

Zielgroesse = FF_GetProfile (RegSchluessel,"Zielgroesse")
if Zielgroesse = "maximale Breite +" then flag_MaxHoehe = 1 else flag_MaxHoehe = 0

Seitenlaenge = FF_GetProfile (RegSchluessel,"Seitenlaenge")
if Seitenlaenge = "" then Seitenlaenge = 1200

Bildhoehe = FF_GetProfile(RegSchluessel,"Bildhoehe")
if Bildhoehe = "" then Bildhoehe = Bildhoehe = "100"

flag_NurVerkleinern = FF_GetProfile (RegSchluessel,"flag_NurVerkleinern")
if flag_NurVerkleinern = "" then flag_NurVerkleinern = 1

'Beschnitt
flag_Beschnitt = FF_GetProfile (RegSchluessel,"flag_Beschnitt")
if flag_Beschnitt = "" then flag_Beschnitt = 0

BelichterName = FF_GetProfile (RegSchluessel,"BelichterName")

FormatIndex = FF_GetProfile (RegSchluessel,"FormatIndex")
if FormatIndex = "" then FormatIndex = 0

SMarkierung = FF_GetProfile (RegSchluessel,"SMarkierung")
if SMarkierung = "" then SMarkierung = 0

flag_BsUeber = FF_GetProfile (RegSchluessel,"flag_BsUeber")
if flag_BsUeber = "" then flag_BsUeber = 1

'Speicheroptionen
flag_Schaerfen = FF_GetProfile (RegSchluessel,"flag_Schaerfen")
if flag_Schaerfen = "" then flag_Schaerfen = 1

SchaerfeWert = FF_GetProfile (RegSchluessel,"SchaerfeWert")
if SchaerfeWert = "" then SchaerfeWert = "mittel"

flag_EI_loeschen = FF_GetProfile (RegSchluessel,"flag_EI_loeschen")
if flag_EI_loeschen = "" then flag_EI_loeschen = 1

'Speicherqualitt
Qualitaet = FF_GetProfile (RegSchluessel,"Qualitaet")
if Qualitaet = "" then Qualitaet = 80

'Speicherort
flag_belOrdner = FF_GetProfile (RegSchluessel,"flag_belOrdner")
if flag_belOrdner = "" then flag_belOrdner = 1

flag_BelichterVerzeichnis = FF_GetProfile (RegSchluessel,"flag_BelichterVerzeichnis")
if flag_BelichterVerzeichnis = "" then flag_BelichterVerzeichnis = 0

Zielordner = FF_GetProfile (RegSchluessel,"Zielordner")
if not objFS.FolderExists(Zielordner) then Zielordner = FF_GetImagePath

'Umbenennung
flag_Umbenennen = FF_GetProfile (RegSchluessel,"flag_Umbenennen")
if flag_Umbenennen = "" then flag_Umbenennen = 0

NameNeu = FF_GetProfile (RegSchluessel,"NameNeu")
if NameNeu = "" then NameNeu = "Bildname"

StAnz = FF_GetProfile (RegSchluessel,"StAnz")
if StAnz = "" then StAnz = 4

mitDatum = FF_GetProfile (RegSchluessel,"mitDatum")
if mitDatum = "" then mitDatum = 0

'### Werte eintragen

'Auswahl
select case Auswahl
	Case 1
		FF_SetControl "ScalePrint","selCV",1
	Case 3
		FF_SetControl "ScalePrint","selBL",1
Case else
End select

'Kopie
FF_SetControl "ScalePrint","flag_Kopie",flag_Kopie
'Zielgre
FF_SetControl "ScalePrint","flag_Ziel",flag_Ziel
if Zielgroesse <> "" then
	FF_SetControl "ScalePrint","Zielgroesse",Zielgroesse
end if
FF_SetControl "ScalePrint","Seitenlaenge",Seitenlaenge
FF_SetControl "ScalePrint","HoeheMax",Bildhoehe
FF_SetControl "ScalePrint","flag_NurVerkleinern",flag_NurVerkleinern

'Beschnitt
FF_SetControl "ScalePrint","flag_Beschnitt",flag_Beschnitt
if BelichterName <> "" and instr(FF_PSGetList,BelichterName) > 0 then
	FF_SetControl "ScalePrint","BelichterName",BelichterName
	for n = 0 to FF_PSGetFormatCount(BelichterName) -1
		FF_SetControl "ScalePrint","BelichterWert",FF_PSGetFormatName(BelichterName,n)
	next
	FF_SetControl "ScalePrint","BelichterWert",FF_PSGetFormatName(BelichterName,FormatIndex)
else
	BelichterName = FF_GetControl("ScalePrint","BelichterName")
	for n = 0 to FF_PSGetFormatCount(BelichterName) -1
		FF_SetControl "ScalePrint","BelichterWert",FF_PSGetFormatName(BelichterName,n)
	next
end if
FF_SetControl "ScalePrint","flag_BsUeber",flag_BsUeber

'Speicheroptionen
FF_SetControl "ScalePrint","flag_Schaerfen",flag_Schaerfen
FF_SetControl "ScalePrint","SchaerfeWert",SchaerfeWert
FF_SetControl "ScalePrint","flag_EI_loeschen",flag_EI_loeschen

'Speicherqualitt
FF_SetControl "ScalePrint","Qualitaet",Qualitaet

'Speicherort
FF_SetControl "ScalePrint","flag_belOrdner",flag_belOrdner
FF_SetControl "ScalePrint","flag_BelichterVerzeichnis",flag_BelichterVerzeichnis
FF_SetControl "ScalePrint","Zielordner",Zielordner

'Umbenennung
FF_SetControl "ScalePrint","flag_Umbenennen",flag_Umbenennen
FF_SetControl "ScalePrint","StAnz",StAnz
FF_SetControl "ScalePrint","NameNeu",NameNeu
FF_SetControl "ScalePrint","mitDatum",mitDatum

End Sub
'---------------------------------------------------------------------
Sub RegistrySchreiben
'Schlsselname = HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Script\ & RegSchluessel

call WerteAuslesen

'Werte schreiben
FF_WriteProfile RegSchluessel,"Auswahl",Auswahl
FF_WriteProfile RegSchluessel,"flag_Kopie",flag_Kopie
FF_WriteProfile RegSchluessel,"flag_Ziel",flag_Ziel
FF_WriteProfile RegSchluessel,"Zielgroesse",Zielgroesse
FF_WriteProfile RegSchluessel,"Seitenlaenge",Seitenlaenge
FF_WriteProfile RegSchluessel,"Bildhoehe",Bildhoehe
FF_WriteProfile RegSchluessel,"flag_NurVerkleinern",flag_NurVerkleinern
FF_WriteProfile RegSchluessel,"flag_Beschnitt",flag_Beschnitt
FF_WriteProfile RegSchluessel,"BelichterName",BelichterName
FF_WriteProfile RegSchluessel,"FormatIndex",FormatIndex
FF_WriteProfile RegSchluessel,"SMarkierung",SMarkierung
FF_WriteProfile RegSchluessel,"flag_BsUeber",flag_BsUeber
FF_WriteProfile RegSchluessel,"flag_Schaerfen",flag_Schaerfen
FF_WriteProfile RegSchluessel,"SchaerfeWert",SchaerfeWert
FF_WriteProfile RegSchluessel,"flag_EI_loeschen",flag_EI_loeschen
FF_WriteProfile RegSchluessel,"Qualitaet",Qualitaet
FF_WriteProfile RegSchluessel,"flag_belOrdner",flag_belOrdner
FF_WriteProfile RegSchluessel,"flag_BelichterVerzeichnis",flag_BelichterVerzeichnis
FF_WriteProfile RegSchluessel,"Zielordner",Zielordner
FF_WriteProfile RegSchluessel,"flag_Umbenennen",flag_Umbenennen
FF_WriteProfile RegSchluessel,"StAnz",StAnz
FF_WriteProfile RegSchluessel,"NameNeu",NameNeu
FF_WriteProfile RegSchluessel,"mitDatum",mitDatum

End Sub
'---------------------------------------------------------------------
Sub Bildschleife
Dim Swert,Nr,Suffix,pos,Datum
Dim FormatPfad,f,fc,Original
Dim strPfad,strName,x

'Solldichte bei Beschnitt
if flag_Beschnitt = 1 then
	SollDichte = FF_PSGetFormatDPI(BelichterName,FormatIndex) * 1
	if Solldichte < 150 and Solldichte <> 1 then
		Antwort = msgbox("Die im Belichterprofil geforderte Punktdichte" & vbNewLine & _
					 	"von " & SollDichte & " dpi ist zu klein!" & vbNewLine & vbNewLine & _
					 	"Soll eine Punktdichte von 300 dpi verwendet werden?",vbQuestion or vbYesNo,"Empfehlung")
		if Antwort = vbYes then SollDichte = 300
	end if
end if
	
'Bilder bearbeiten

for b = 0 to imgAnz - 1
	
	'### Test ob Bild vorhanden, sonst Abbruch
	if not objFS.FileExists(Array(b)) then
		msgbox "Die Datei " & Array(b) & " wurde bereits gelscht" & vbNewLine & _
		  	   "Bitte die Bilder aktualisieren und es dann erneut versuchen!",vbExclamation,"Abbruch"
		exit sub
	end if

	'### Abbruch?
	if FF_CheckKey() = 8 then 	'8 = Backspace
		Antwort = msgbox("Von " & imgAnz & " Dateien wurden bisher " & b & _
						 " Bilder skaliert." & vbNewLine & vbNewLine & _
						 "Soll die Skalierung abgebrochen werden?",vbYesNo or vbQuestion,"Abfrage")
		if Antwort = vbYes then exit sub
	end if

	'### Fortschrittsanzeige
	FF_SetControl "ScalePrint","Fortschritt",(b+1)/imgAnz*100

	'### Bildfilter anwenden
	strExtension = ucase(objFS.GetExtensionName(Array(b)))
	if strExtension <> "" and instr(BildFilter,":" & strExtension & ":") > 0 then

		'### Laden
		on error resume next
		FF_LoadImage(Array(b))
		if err.number > 0 then
			msgbox "Die Bilddatei" & vbNewline & Array(b) & vbNewLine & "ist defekt!" & vbNewLine & vbNewline &_
				   "Bitte die defekte Datei aus der Auswahl entfernen." ,vbExclamation,"Abbruch"
			exit sub
		end if
		on error goto 0
		Bildname = objFS.GetBaseName(Array(b))
		
		if flag_Kopie = 0 then

			'### Geometriebestimmungen
			IstBreite = FF_GetImageWidth
			IstHoehe = FF_GetImageHeight
			SV_BzuH = IstBreite / IstHoehe
	
			if flag_Ziel = 1 then
				call Ziel_Sollwerte
			elseif flag_Beschnitt = 1 then
				Uebersprung = false
				call Beschnitt_Sollwerte
			end if
			
			if Abbruch then exit sub
			
			if not Uebersprung then
				
				'### Skalieren
				if flag_MaxHoehe = 1 then
					FF_HQScale SollBreite,SollHoehe,true
				else
					FF_HQScale SollBreite,SollHoehe,false
				end if
				
				'### Schrfen
				if flag_Schaerfen = 1 then
					select case SchaerfeWert
						case "schwach"
							Swert = S_schwach
						case "mittel"
							Swert = S_mittel
						case "stark"
							Swert = S_stark
					case else
						msgbox "Schwerer Schrfe-Fehler!",vbExclamation,"Abbruch"
						exit sub
					end select
				
					if RGB_S then FF_Sharp Swert,true,true,true
					if Y_S then FF_YSharp Swert
				end if
				
			end if
		end if
		
		if not Uebersprung then
			
			'### Benennen
			strExtension = "." & strExtension
					
			if flag_Umbenennen = 1 then
	
				Nr = k + b +1										'### Bildnummer wird festgelegt
				
				x = 4 - StAnz + len(Nr)								'### vorlaufende Nullen festlegen
				if x > 4 then
					msgbox "Schwerer Nummerierungs-Fehler!",vbExclamation,"Abbruch"
					exit sub
				end if
	
				select case x
					case 1
						Suffix = "_000" & Nr
					case 2
						Suffix = "_00" & Nr
					case 3
						Suffix = "_0" & Nr
					case 4
						Suffix = "_" & Nr
				case else
					msgbox "Schwerer Nummerierungs-Fehler!",vbExclamation,"Abbruch"
					exit sub
				end select
				
				Bildname = Zielordner & "\" & NameNeu & Suffix
	
				if mitDatum = 1 then
					Datum = left(FF_GetExifTag ("DateTimeOriginal"),10)
					if len(Datum) = 0 then
						Datum = "tt.mm.jjjj"
					else
						Datum = right(Datum,2) & "." & mid(Datum,6,2) & "." & left(Datum,4)
					end if
					Bildname = Bildname & "_" & Datum	
				end if
	
			else
				Bildname = Zielordner & "\" & Bildname
			end if

			Bildname = Bildname & strExtension
			
			if flag_BelichterVerzeichnis = 1 then
				FormatPfad = objFS.BuildPath(Belichterpfad,BelichterWert)
				if not objFS.FolderExists(FormatPfad) then
					Set f  = objFS.GetFolder(Belichterpfad)
					Set fc = f.SubFolders
					Set FormatPfad = fc.Add(BelichterWert)
				end if
				
				Bildname = objFS.GetFileName(Bildname)
				Bildname = objFS.BuildPath(FormatPfad,Bildname)
			end if
	
			'Bildname trennen in Pfad und Bildname ohne Extension
			strPfad  = objFS.GetParentFolderName(Bildname)
			strName  = objFS.GetBaseName(Bildname)
			Bildname = objFS.BuildPath(strPfad,strName)
	
			'### vorhandene Bilder nummerieren mit (1), (2) usw. wenn bereits vorhanden
			if objFS.FileExists(Bildname & strExtension) then
				n = 1
				do
					if not objFS.FileExists(Bildname & "(" & n & ")" & strExtension) then exit do
					n = n + 1
				loop
				Bildname = Bildname & "(" & n & ")" & strExtension
			else
				Bildname = Bildname & strExtension
			end if
	
			'### Kopieren oder Speichern, ggf. mit Lschen von Exif-Daten
			if flag_Kopie = 1 then
				Set Original = objFS.GetFile(Array(b))
				Original.Copy(Bildname)
			else
				FF_SaveImage Bildname,Qualitaet
				if flag_EI_loeschen = 1 then
					FF_KillExifData Bildname
					FF_KillIPTCData Bildname
				end if
			end if

		else
			k = k -1
		end if
		
end if
next

End Sub
'---------------------------------------------------------------------
Sub Ziel_Sollwerte

Select Case Zielgroesse
	Case "lngste Seite"
		if IstBreite >= IstHoehe then
	 		if flag_NurVerkleinern = 0 or IstBreite >= Seitenlaenge then
	 			SollBreite = Seitenlaenge
	 			SollHoehe = round(Seitenlaenge / SV_BzuH)
	 		else
	 			SollBreite = IstBreite
	 			SollHoehe = IstHoehe
	 		end if
	 	else
	 		if flag_NurVerkleinern = 0 or IstHoehe >= Seitenlaenge then
	 			SollBreite = round(Seitenlaenge * SV_BzuH)
	 			SollHoehe = Seitenlaenge
	 		else
	 			SollBreite = IstBreite
	 			SollHoehe = IstHoehe
	 		end if
	 	end if
	Case "krzeste Seite"
		if IstBreite <= IstHoehe then
	 		if flag_NurVerkleinern = 0 or IstBreite >= Seitenlaenge then
	 			SollBreite = Seitenlaenge
	 			SollHoehe = round(Seitenlaenge / SV_BzuH)
	 		else
	 			SollBreite = IstBreite
	 			SollHoehe = IstHoehe
	 		end if
	 	else
	 		if flag_NurVerkleinern = 0 or IstHoehe >= Seitenlaenge then
	 			SollBreite = round(Seitenlaenge * SV_BzuH)
	 			SollHoehe = Seitenlaenge
	 		else
	 			SollBreite = IstBreite
	 			SollHoehe = IstHoehe
	 		end if
	 	end if
	Case "maximale Breite"
		if flag_NurVerkleinern = 0 or IstBreite >= Seitenlaenge then
			SollBreite = Seitenlaenge
			SollHoehe = round(Seitenlaenge / SV_BzuH)
		else
 			SollBreite = IstBreite
 			SollHoehe = IstHoehe
 		end if
	Case "maximale Hhe"
		if flag_NurVerkleinern = 0 or IstHoehe >= Seitenlaenge then
			SollBreite = round(Seitenlaenge * SV_BzuH)
			SollHoehe = Seitenlaenge
		else
 			SollBreite = IstBreite
 			SollHoehe = IstHoehe
 		end if
 	Case "maximale Breite +"
 		if flag_NurVerkleinern = 0 or IstBreite >= Seitenlaenge or IstHoehe >= Bildhoehe then
 			SollBreite = Seitenlaenge
 			SollHoehe = Bildhoehe
 		else
 			SollBreite = IstBreite
 			SollHoehe = IstHoehe
 		end if
Case else
	msgbox "Schwerer Kantenlngen-Fehler!",vbExclamation,"Abbruch"
	Abbruch = true
End Select

End Sub
'---------------------------------------------------------------------
Sub Beschnitt_Sollwerte
Dim SollHoehe_cm,SollBreite_cm
Dim ZielHoehePx,ZielBreitePx
Dim SParameter,AntwortMD,PArray
Dim SollTemp

'Ermittlung der Sollwerte
if IstBreite >= IstHoehe then
	SollHoehe_cm = FF_PSGetFormatHeight(BelichterName,FormatIndex)
	SollBreite_cm = FF_PSGetFormatWidth(BelichterName,FormatIndex)
else
	SollHoehe_cm = FF_PSGetFormatWidth(BelichterName,FormatIndex)
	SollBreite_cm = FF_PSGetFormatHeight(BelichterName,FormatIndex)
end if

SollHoehe = round(SollHoehe_cm * SollDichte / 2.54)
SollBreite = round(SollBreite_cm * SollDichte / 2.54)
SV_Soll = SollBreite / SollHoehe

if flag_BsUeber = 0 or abs(SV_BzuH - SV_Soll) > (Toleranz * SV_BzuH / 100) then 'max. 3% Abweichung (Toleranz)

	'### Schnittdialog
	ZielHoehePx  = IstHoehe
	ZielBreitePx = round(IstHoehe * SV_Soll)
	if ZielBreitePx > IstBreite then
		ZielBreitePx = IstBreite
		ZielHoehePx = round(IstBreite / SV_Soll)
	end if
	SParameter = "0,0," & ZielBreitePx & "," & ZielHoehePx & "," & IstBreite & "," & IstHoehe & "," & SMarkierung & ",1"
	FF_SetParam SParameter
	
	do
		AntwortMD = FF_MultiDialog ("MultiCanvas",2)
		FF_Sleep 100
		if AntwortMD < 0 then
			Antwort = msgbox("Das Bild wurde nicht beschnitten!" & vbNewLine & _ 
							 "Soll das Bild bersprungen werden?",vbQuestion + vbYesNoCancel,"Mit 'Abbrechen' wird das Skript beendet")
			'msgbox "Das Bild wurde nicht beschnitten!" & vbNewLine & _
			'	   "Der Dialog muss unbedingt mit 'Ausfhren' beendet werden.",vbInformation,"Hinweis"
			if Antwort = vbYes then
				Uebersprung = true : exit sub
			elseif Antwort = vbCancel then
				Abbruch = true : exit sub
			end if
		else
			exit do
		end if
	loop
	
	PArray = split(FF_GetParam(),",")
	SMarkierung = PArray(6)
	
	'### Istwerte neu bestimmen und ggf. Sollwerte tauschen
	IstHoehe  =	FF_GetImageHeight() * 1
	IstBreite = FF_GetImageWidth() * 1

	if (IstHoehe >= IstBreite) xor (SollHoehe >= SollBreite) then
		SollTemp = SollBreite
		SollBreite = SollHoehe
		SollHoehe = SollTemp
	end if

end if

'### Punkdichte bewerten
IstDichte = round(IstHoehe / SollHoehe_cm * 2.54)
if Istdichte < SollDichte then
	if PunktdichteNie then
		SollBreite = IstBreite
		SollHoehe = IstHoehe
		FF_SetDPI IstDichte
	elseif PunktdichteImmer then
		FF_SetDPI SollDichte
	else
		call Abfrage_Punktdichte
	end if
else
	FF_SetDPI SollDichte
end if

End Sub
'---------------------------------------------------------------------
Sub Abfrage_Punktdichte

'** Start Dialog Punktdichte **
FF_AddDialog "Punktdichte",126,78
FF_AddControl "Punktdichte","Von der geforderten Punkdichte ","STATIC",5,5,82,10
FF_AddControl "Punktdichte","Sdpi","SLEDIT",87,5,18,10
FF_SetControlStyle "Punktdichte","Sdpi",2049
FF_AddControl "Punktdichte","dpi","STATIC",109,5,10,10
FF_AddControl "Punktdichte","werden nur erreicht","STATIC",5,16,82,10
FF_AddControl "Punktdichte","Idpi","SLEDIT",87,16,18,10
FF_SetControlStyle "Punktdichte","Idpi",2049
FF_AddControl "Punktdichte","dpi|","STATIC",109,16,10,10
FF_AddControl "Punktdichte","Soll hoch skaliert werden?","STATIC",30,32,62,10
FF_AddControl "Punktdichte","Nein","BUTTON",11,47,33,11
FF_AddControl "Punktdichte","Nie","BUTTON",11,62,33,11
FF_AddControl "Punktdichte","Ja","BUTTON",73,46,33,12
FF_AddControl "Punktdichte","Immer","BUTTON",73,62,33,11
'** End Dialog Punktdichte **

FF_SetControl "Punktdichte","Sdpi",Solldichte
FF_SetControl "Punktdichte","Idpi",Istdichte
'Msgbox "SB = " & SollBreite & " / IB = " & IstBreite & " / SH = " & SollHoehe & " / IH = " & IstHoehe
do
	Select Case FF_ShowDialog ("Punktdichte")
		Case "Nein"
			SollBreite = IstBreite
			SollHoehe = IstHoehe
			FF_SetDPI IstDichte
			exit do
		Case "Nie"
			SollBreite = IstBreite
			SollHoehe = IstHoehe
			FF_SetDPI IstDichte
			PunktdichteNie = true
			exit do
		Case "Ja"
			FF_SetDPI SollDichte
			exit do
		Case "Immer"
			FF_SetDPI SollDichte
			PunktdichteImmer = true
			exit do
		Case "CANCEL"
			FF_SetDPI SollDichte
			exit do
	Case Else
		msgbox "Schwerer Punktdichte-Fehler!",vbExclamation,"Abbruch"
		Abbruch = true
		exit do
	End Select
loop

FF_CloseDialog ("Punktdichte")

End Sub
'---------------------------------------------------------------------
Sub BelPfad_Lesen
'Belichterverzeichnis auslesen und prfen

	on error resume next
	BelichterPfad = WshShell.RegRead (Reg_BildV)
	if err.number > 0 then
		msgbox "Der Wert ProviderPath ist im Registry-Schlssel" & _
			   "HKEY_CURRENT_USER\Software\Joachim Koopmann Software\FixFoto\Options" & _
			   "nicht zu finden!",vbExclamation,"Meldung"
		Abbruch = true
		exit sub
	end if
	on error goto 0

	if len(BelichterPfad) = 0 then
		msgbox "Es ist kein Belichterverzeichnis in" & vbNewLine & _
			   "in den FF-Einstellungen unter Pfade zu finden!",vbExclamation,"Meldung"
		Abbruch = true
		exit sub
	end if

	if not objFS.FolderExists(BelichterPfad) then
		msgbox "Das in den FF-Einstellungen angegebene Belichterverzeichnis" & vbNewLine & _
		    BelichterPfad & vbNewLine & _
		   "existiert nicht!",vbExclamation,"Meldung"
		Abbruch = true
		exit sub
	end if

End Sub
'---------------------------------------------------------------------
Function MaxNummer(OrdnerAngabe,FilterAngabe)
   Dim f,f1,fc,bb,MBild,pos,nr
   Set f = objFS.GetFolder(OrdnerAngabe)
   Set fc = f.Files
   For Each f1 in fc
		if instr(f1.Name,FilterAngabe) = 1 then
			bb = objFS.GetBaseName(f1.Name)
			pos = InStrRev(bb,"_")
			if pos > 0 then 
				nr = mid(bb,pos +1)
				if IsNumeric(nr) and nr > MBild then MBild = nr
			end if
		end if
   Next
   MaxNummer = MBild
End Function
'************************************************************************
'Update-Funktion
'************************************************************************
Sub Update
Dim Antwort

call Versionsermittlung_url

if not Abbruch then
	SkriptV_Zahl = Replace(SkriptVersion,".","") *1
	
	if UrlV_Zahl = SkriptV_Zahl then
		msgbox "Die Version " & SkriptVersion & " ist aktuell!",vbInformation,"Versionsmeldung"
	elseif SkriptV_Zahl < UrlV_Zahl then
		Antwort = msgbox("Die Skriptversion " & SkriptVersion & " ist nicht mehr aktuell!" & vbNewLine &_
				"Es steht die Version " & UrlVersion & " zum Download bereit." & vbNewLine & vbNewLine & _
				"Soll die Downloadseite aufgerufen werden?",vbQuestion + vbYesNo,"Versionsmeldung")
		if Antwort = vbYes then
			on error resume next
			WshShell.Run SkriptUrl,1,false
			if err <> 0 then
				msgbox "Die Downloadseite wurde nicht gefunden!",vbExclamation,"Hinweis"
			else
				SkriptEnde = true
			end if
			on error goto 0
		end if
	else
		msgbox 	"Es liegt ein Fehler in den Versionsangaben vor." & vbNewLine &_
				"Die Skriptversion " & SkriptVersion & " ist grer als die auf" & vbNewLine &_
				"der Downloadseite angegebene Version " & UrlVersion & ".",vbInformation,"Fehlermeldung"
	end if
end if

End Sub
'------------------------------------------------------------------------
Sub Versionsermittlung_url

const VersVortext = "Version:"
Dim Inhalt,pos1,pos2,xml
Dim Fehler : Fehler = false

on error resume next

Set xml = CreateObject("Microsoft.XMLHTTP")
xml.Open "Get",SkriptUrl,false
xml.Send

Inhalt = xml.responseText

if err <> 0 then
	Fehler = true
else
	'Version suchen und anzeigen	
	pos1 = instr(Inhalt,VersVortext)
	if pos1 > 0 then
		pos2 = instr(pos1 ,Inhalt,".")
		if pos2 > 0 then
			pos2 = pos2 +3
			UrlVersion = trim(mid(Inhalt,pos1,pos2-pos1))
		else
			Fehler = true
		end if
	else
		Fehler = true
	end if
end if

Set xml = nothing
On Error GoTo 0

if Fehler then
	msgbox  "Die Versionsangabe wurde nicht gefunden!" & vbNewLine &_
			"Mglicherweise funktioniert der Internetaufruf nicht." & vbNewLine & vbNewLine & _
			"Am besten nochmal probieren!",vbExclamation,"Fehlermeldung"
	Abbruch = true
	exit sub
end if

'Version als Zahl
UrlVersion = trim(mid(UrlVersion,len(VersVortext) +1))
UrlV_Zahl = Replace(UrlVersion,".","") *1

End Sub
'------------------------------------------------------------------------
